==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/connect/kotlin/outputs/UserHierarchyStructureHierarchyStructure.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.connect.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property levelFive A block that defines the details of level five. The level block is documented below.
 * Each level block supports the following arguments:
 * @property levelFour A block that defines the details of level four. The level block is documented below.
 * @property levelOne A block that defines the details of level one. The level block is documented below.
 * @property levelThree A block that defines the details of level three. The level block is documented below.
 * @property levelTwo A block that defines the details of level two. The level block is documented below.
 */
public data class UserHierarchyStructureHierarchyStructure(
    public val levelFive: UserHierarchyStructureHierarchyStructureLevelFive? = null,
    public val levelFour: UserHierarchyStructureHierarchyStructureLevelFour? = null,
    public val levelOne: UserHierarchyStructureHierarchyStructureLevelOne? = null,
    public val levelThree: UserHierarchyStructureHierarchyStructureLevelThree? = null,
    public val levelTwo: UserHierarchyStructureHierarchyStructureLevelTwo? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.connect.outputs.UserHierarchyStructureHierarchyStructure):
            UserHierarchyStructureHierarchyStructure = UserHierarchyStructureHierarchyStructure(
            levelFive = javaType.levelFive().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.UserHierarchyStructureHierarchyStructureLevelFive.Companion.toKotlin(args0)
                })
            }).orElse(null),
            levelFour = javaType.levelFour().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.UserHierarchyStructureHierarchyStructureLevelFour.Companion.toKotlin(args0)
                })
            }).orElse(null),
            levelOne = javaType.levelOne().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.UserHierarchyStructureHierarchyStructureLevelOne.Companion.toKotlin(args0)
                })
            }).orElse(null),
            levelThree = javaType.levelThree().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.UserHierarchyStructureHierarchyStructureLevelThree.Companion.toKotlin(args0)
                })
            }).orElse(null),
            levelTwo = javaType.levelTwo().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.UserHierarchyStructureHierarchyStructureLevelTwo.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/connect/kotlin/outputs/UserHierarchyStructureHierarchyStructure.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.connect.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property levelFive A block that defines the details of level five. The level block is documented below.
 * Each level block supports the following arguments:
 * @property levelFour A block that defines the details of level four. The level block is documented below.
 * @property levelOne A block that defines the details of level one. The level block is documented below.
 * @property levelThree A block that defines the details of level three. The level block is documented below.
 * @property levelTwo A block that defines the details of level two. The level block is documented below.
 */
public data class UserHierarchyStructureHierarchyStructure(
    public val levelFive: UserHierarchyStructureHierarchyStructureLevelFive? = null,
    public val levelFour: UserHierarchyStructureHierarchyStructureLevelFour? = null,
    public val levelOne: UserHierarchyStructureHierarchyStructureLevelOne? = null,
    public val levelThree: UserHierarchyStructureHierarchyStructureLevelThree? = null,
    public val levelTwo: UserHierarchyStructureHierarchyStructureLevelTwo? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.connect.outputs.UserHierarchyStructureHierarchyStructure): UserHierarchyStructureHierarchyStructure = UserHierarchyStructureHierarchyStructure(
            levelFive = javaType.levelFive().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.UserHierarchyStructureHierarchyStructureLevelFive.Companion.toKotlin(args0)
                })
            }).orElse(null),
            levelFour = javaType.levelFour().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.UserHierarchyStructureHierarchyStructureLevelFour.Companion.toKotlin(args0)
                })
            }).orElse(null),
            levelOne = javaType.levelOne().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.UserHierarchyStructureHierarchyStructureLevelOne.Companion.toKotlin(args0)
                })
            }).orElse(null),
            levelThree = javaType.levelThree().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.UserHierarchyStructureHierarchyStructureLevelThree.Companion.toKotlin(args0)
                })
            }).orElse(null),
            levelTwo = javaType.levelTwo().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.UserHierarchyStructureHierarchyStructureLevelTwo.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}
